import {
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  scaleOrdinal,
} from 'd3';

export const scatterPlot = () => {
  let width;
  let height;
  let data;
  let xValue;
  let yValue;
  let margin;
  let radius;

  const my = (selection) => {
    const x = scaleLinear() // to create x-axis
      .domain(extent(data, xValue))
      .range([margin.left, width - margin.right]);

    const y = scaleLinear() // to create y-axis
      .domain(extent(data, yValue))
      .range([height - margin.bottom, margin.top]);
    
    const getSpeciesColor = (d) => { // to select the color for the species
        	switch(d.species){
            case 'setosa':
              return 'blue';
            case 'versicolor':
              return 'orange';
            default:
              return 'red';
          }
        }
    
    
       
    const marks = data.map((d) => ({
      x: x(xValue(d)),
      y: y(yValue(d)),
      color: getSpeciesColor(d),
      
    }));
    

    const circles = selection // to mark circle data points on the chart
      .selectAll('circle')
      .data(marks)
      .join('circle')
      .attr('cx', (d) => d.x)
      .attr('cy', (d) => d.y)
      .attr('r', radius)
    	.attr('fill', (d) => d.color)


    selection // to add y-axis
      .selectAll('.y-axis')
      .data([null])
      .join('g')
      .attr('class', 'y-axis')
      .attr('transform', `translate(${margin.left},0)`)
      .call(axisLeft(y));

    selection // to add x-axis
      .selectAll('.x-axis')
      .data([null])
      .join('g')
      .attr('class', 'x-axis')
      .attr(
        'transform',
        `translate(0,${height - margin.bottom})`
      )
      .call(axisBottom(x));
  };
  
  
  my.width = function (_) {
    return arguments.length ? ((width = +_), my) : width;
  };

  my.height = function (_) {
    return arguments.length ? ((height = +_), my) : height;
  };

  my.data = function (_) {
    return arguments.length ? ((data = _), my) : data;
  };

  my.xValue = function (_) {
    return arguments.length ? ((xValue = _), my) : xValue;
  };

  my.yValue = function (_) {
    return arguments.length ? ((yValue = _), my) : yValue;
  };

  my.margin = function (_) {
    return arguments.length ? ((margin = _), my) : margin;
  };

  my.radius = function (_) {
    return arguments.length ? ((radius = +_), my) : radius;
  };

  return my;
};